==> appfs-21.02.tar.gz: usr/local/www/berogui/misc/files_download.php <==
<?php

# check if session is valid
$newTarget = '/app/berogui/index.php';
require_once('/usr/local/www/berogui/includes/session.php');
unset($newTarget);

/**
 * @file
 * Lädt verschiedene Dateien aus dem Dateisystem herunter
 */
include('/usr/php/include/configExportImportTool.class.php');
require_once('/usr/local/www/berogui/includes/Helper/Helper.php');

switch ($_GET['option']) {
	case 'BEROFIX-MIB':
		$file = implode('', file('/usr/local/conf/BEROFIX-MIB.txt'));
		$filename = 'BEROFIX-MIB.txt';
		break;
	case 'certificate':
		if ($_GET['file'] == 'cafile'){
			$file = implode('', file('/usr/conf/cafile.pem'));
			$filename = 'cafile.pem';
		}
		elseif ($_GET['file'] == 'agent') {
			$file = implode('', file('/usr/conf/agent.pem'));
			$filename = 'agent.pem';
		}
		else if ($_GET['file'] == 'cafile_lan'){
			$file = implode('', file('/usr/conf/cafile_lan.pem'));
			$filename = 'cafile_lan.pem';
		}
		elseif ($_GET['file'] == 'agent_lan') {
			$file = implode('', file('/usr/conf/agent_lan.pem'));
			$filename = 'agent_lan.pem';
		}
		else if ($_GET['file'] == 'cafile_wan'){
			$file = implode('', file('/usr/conf/cafile_wan.pem'));
			$filename = 'cafile_wan.pem';
		}
		elseif ($_GET['file'] == 'agent_wan') {
			$file = implode('', file('/usr/conf/agent_wan.pem'));
			$filename = 'agent_wan.pem';
		}
		break;
		
	case 'certificate_https':
		$file = implode('', file('/usr/conf/berofix.pem'));
		$filename = 'berofix.pem';
		break;
	case 'vpn-client-conf-dl':
		require_once('/usr/local/php/include/beronode/VpnApi.php');
		$vpn_api = new VpnApi();
		$file = $vpn_api->clientDownloadConfiguration(0);
		$check_res = json_decode($file, true);
		if (isset($check_res['error'])) {
			echo "<script>window.location='../index.php?m=Vpn&error=3&reason={$check_res['error']}';</script>";
			exit(0);
		}
		$filename = 'client.conf';
		break;
	default:
		$exp = new configExportImportTool();
		$file = $exp->exportConfig();
		$ba = new beroAri();
		$is_sbc_vm = $ba->get('is_sbc_vm');
		$basename = "beroNetVoIPGateway_";
		if ($is_sbc_vm) {
			$basename = "beroNetCloudSbc_";
		}
		$filename = $basename . Helper::getSerial() . '_' . Helper::getDate('"+%c"') . '.config.xml';
		break;
}

header('Content-Type: application/force-download');
header('Content-Disposition: attachment; filename="' . $filename . '"' . "\r\n\r\n");
header('Content-Length: ' . strlen($file) . "\n\n");
echo $file;

exit(0);
?>

==> appfs-24.01.01-rc37.tar.gz: usr/local/www/berogui/misc/files_download.php <==
<?php

# check if session is valid
$newTarget = '/app/berogui/index.php';
require_once('/usr/local/www/berogui/includes/session.php');
unset($newTarget);

/**
 * @file
 * Lädt verschiedene Dateien aus dem Dateisystem herunter
 */
include('/usr/php/include/configExportImportTool.class.php');
require_once('/usr/local/www/berogui/includes/Helper/Helper.php');

switch ($_GET['option']) {
	case 'BEROFIX-MIB':
		$file = implode('', file('/usr/local/conf/BEROFIX-MIB.txt'));
		$filename = 'BEROFIX-MIB.txt';
		break;
	case 'certificate':
		if ($_GET['file'] == 'cafile'){
			$file = implode('', file('/usr/conf/cafile.pem'));
			$filename = 'cafile.pem';
		}
		elseif ($_GET['file'] == 'agent') {
			$file = implode('', file('/usr/conf/agent.pem'));
			$filename = 'agent.pem';
		}
		else if ($_GET['file'] == 'cafile_lan'){
			$file = implode('', file('/usr/conf/cafile_lan.pem'));
			$filename = 'cafile_lan.pem';
		}
		elseif ($_GET['file'] == 'agent_lan') {
			$file = implode('', file('/usr/conf/agent_lan.pem'));
			$filename = 'agent_lan.pem';
		}
		else if ($_GET['file'] == 'cafile_wan'){
			$file = implode('', file('/usr/conf/cafile_wan.pem'));
			$filename = 'cafile_wan.pem';
		}
		elseif ($_GET['file'] == 'agent_wan') {
			$file = implode('', file('/usr/conf/agent_wan.pem'));
			$filename = 'agent_wan.pem';
		}
		break;
	case 'certificate_https':
		$file = implode('', file('/usr/conf/berofix.pem'));
		$filename = 'berofix.pem';
		break;
	case 'provisioning-cc':
		$file = file_get_contents('/usr/conf/tls/client.crt');
		$filename = 'client.crt';
		break;
	case 'vpn-client-conf-dl':
		require_once('/usr/local/php/include/beronode/VpnApi.php');
		$vpn_api = new VpnApi();
		$file = $vpn_api->clientDownloadConfiguration(0);
		$check_res = json_decode($file, true);
		if (isset($check_res['error'])) {
			echo "<script>window.location='../index.php?m=Vpn&error=3&reason={$check_res['error']}';</script>";
			exit(0);
		}
		$filename = 'client.conf';
		break;
	default:
		$exp = new configExportImportTool();
		if ($_GET['configFiles']==null) $configFiles = array();
		else{
			 $configFiles = $_GET["configFiles"];
			 $configFiles = $exp->fileGroupsToFiles($configFiles);
		}
		if ($_GET['importOptions']==null) $options = true;
		else $options = $_GET["importOptions"];
		$file = $exp->exportConfig($configFiles,$options);
		if ($file === false || $exp->hasError()) {
			$error = $exp->getError();
			echo "<script>window.location='../index.php?m=BackupRestore&error={$error['whichOne']}&more={$error['more']}';</script>";
			exit(0);
		}
		$ba = new beroAri();
		$is_sbc_vm = $ba->get('is_sbc_vm');
		$basename = "beroNetVoIPGateway_";
		if ($is_sbc_vm) {
			$basename = "beroNetCloudSbc_";
		}
		
		$firmware_version = Helper::getFirmwareVersion ();
		if (strlen ($firmware_version)) {
			$firmware_version = "_" . $firmware_version;
		}
		
		$filename = $basename . Helper::getSerial() . '_' . Helper::getDateByFormat("+%Y%m%d_%H%M%S") . $firmware_version .'.config.xml';
		break;
}

header('Content-Type: application/force-download');
header('Content-Disposition: attachment; filename="' . $filename . '"' . "\r\n\r\n");
header('Content-Length: ' . strlen($file) . "\n\n");
echo $file;

exit(0);
?>
